System.import('./clients.js');
System.import('./obvdoc.js').then(function(obvdoc) {

    /**
     * 一个用来加载 Doc 文件的加载器
     */
    class DocFileLoader {
        constructor(inputId) {
            this.fileInfo = {
                fileName: 'load file first',
            };
            this.inputId=inputId;
        }
        async load() {
            const inputVal=this._getInfo();
            const viewingOptionsParams=new URL(inputVal.obvEnv);
            // this.fileInfo.fileName = file;
            const viewingOptions = new ViewingServiceOptions(
                viewingOptionsParams.hostname,
                viewingOptionsParams.port,
                viewingOptionsParams.protocol,
                '/bimserver/viewing/v3'
            );
            const authOptions = new AuthServiceOptions(
                viewingOptionsParams.hostname,
                viewingOptionsParams.port,
                viewingOptionsParams.protocol,
                '/bimserver/auth'
            );
            const credentials = new AuthCredentials(inputVal.clientId, inputVal.clientSceret, 'client_credentials');
            const authClient=new AuthClient();
            const tokenInfo =await authClient.getToken(authOptions, credentials);
            const viewingClient=new ViewingClient();
            const encodedUrn = inputVal.urn;
            const item = await viewingClient.getItemAsArrayBuffer(encodedUrn, tokenInfo.accessToken, viewingOptions);
            return item;
        }

        _getInfo(){
            let clientId=document.getElementById('clientId').value;
            let clientSceret=document.getElementById('clientSceret').value;
            let urn=document.getElementById(this.inputId).value;
            let obvEnv=document.getElementById('obvEnv').value;
            return {clientId,clientSceret,urn,obvEnv}
        }
    }

    /**
     * 创建一个有 GUI 的 DocViewer
     * 并初始化 docFileLoader 等依赖的对象
     */
    class MyGuiViewer {
        constructor() {
            this.docViewer = new obvdoc.default.Viewer();
            this.options = this.docViewer.viewerAppOptions;
            // 设置 workerSrc 从当前的路径中获取pdf.worker.js, 复写 app_options.js 中的配置
            this.options.set('workerSrc', 'obvdoc.worker.js');
            // 启用 webgl，增强显示效果。TODO， are you sure?
            this.options.set('enableWebGL', true);
            // 设置资源的加载位置
            this.options.set('cMapUrl', './cmaps/');
            this.options.set('cMapUrl', './images/');
        }

        createViewerContainer(assemblyId) {
            const div = document.createElement('div');
            div.id = `${assemblyId.prefix}${assemblyId.suffix}`;
            div.tabIndex = 1;
            div.className = 'loadingInProgress';
            div.style.width = '800px';
            div.style.height = '600px';
            return div;
        }

        createOuterContainer(assemblyId) {
            const outerDiv = document.createElement('div');
            const suffix=assemblyId.suffix;
            outerDiv.id=`outerContainer${suffix}`;
            outerDiv.innerHTML = `
<!--<div id="sidebarContainer${suffix}">-->
        <!--<div id="toolbarSidebar${suffix}">-->
            <!--<div class="splitToolbarButton toggled">-->
                <!--<button id="viewThumbnail${suffix}" class="toolbarButton toggled" title="Show Thumbnails" tabindex="2" data-l10n-id="thumbs">-->
                    <!--<span data-l10n-id="thumbs_label">Thumbnails</span>-->
                <!--</button>-->
                <!--<button id="viewOutline${suffix}" class="toolbarButton" title="Show Document Outline (double-click to expand/collapse all items)" tabindex="3" data-l10n-id="document_outline">-->
                    <!--<span data-l10n-id="document_outline_label">Document Outline</span>-->
                <!--</button>-->
                <!--<button id="viewAttachments${suffix}" class="toolbarButton" title="Show Attachments" tabindex="4" data-l10n-id="attachments">-->
                    <!--<span data-l10n-id="attachments_label">Attachments</span>-->
                <!--</button>-->
            <!--</div>-->
        <!--</div>-->
        <!--<div id="sidebarContent">-->
            <!--<div id="thumbnailView${suffix}">-->
            <!--</div>-->
            <!--<div id="outlineView${suffix}" class="hidden">-->
            <!--</div>-->
            <!--<div id="attachmentsView${suffix}" class="hidden">-->
            <!--</div>-->
        <!--</div>-->
        <!--<div id="sidebarResizer${suffix}" class="hidden"></div>-->
    <!--</div>&lt;!&ndash; sidebarContainer &ndash;&gt;-->

<div id="mainContainer">
        <div class="findbar hidden doorHanger" id="findbar${suffix}">
            <div id="findbarInputContainer">
                <input id="findInput${suffix}" class="toolbarField" title="Find" placeholder="Find in document…" tabindex="91" data-l10n-id="find_input">
                <div class="splitToolbarButton">
                    <button id="findPrevious${suffix}" class="toolbarButton findPrevious" title="Find the previous occurrence of the phrase" tabindex="92" data-l10n-id="find_previous">
                        <span data-l10n-id="find_previous_label">Previous</span>
                    </button>
                    <div class="splitToolbarButtonSeparator"></div>
                    <button id="findNext${suffix}" class="toolbarButton findNext" title="Find the next occurrence of the phrase" tabindex="93" data-l10n-id="find_next">
                        <span data-l10n-id="find_next_label">Next</span>
                    </button>
                </div>
            </div>

            <div id="findbarOptionsOneContainer">
                <input type="checkbox" id="findHighlightAll${suffix}" class="toolbarField" tabindex="94">
                <label for="findHighlightAll${suffix}" class="toolbarLabel" data-l10n-id="find_highlight">Highlight all</label>
                <input type="checkbox" id="findMatchCase${suffix}" class="toolbarField" tabindex="95">
                <label for="findMatchCase${suffix}" class="toolbarLabel" data-l10n-id="find_match_case_label">Match case</label>
            </div>
            <div id="findbarOptionsTwoContainer">
                <input type="checkbox" id="findEntireWord${suffix}" class="toolbarField" tabindex="96">
                <label for="findEntireWord${suffix}" class="toolbarLabel" data-l10n-id="find_entire_word_label">Whole words</label>
                <span id="findResultsCount${suffix}" class="toolbarLabel hidden"></span>
            </div>

            <div id="findbarMessageContainer">
                <span id="findMsg${suffix}" class="toolbarLabel"></span>
            </div>
        </div>  <!-- findbar -->

        <!--<div id="secondaryToolbar${suffix}" class="secondaryToolbar hidden doorHangerRight">-->
            <!--<div id="secondaryToolbarButtonContainer${suffix}">-->
                <!--<button id="secondaryPresentationMode${suffix}" class="secondaryToolbarButton presentationMode visibleLargeView" title="Switch to Presentation Mode" tabindex="51" data-l10n-id="presentation_mode">-->
                    <!--<span data-l10n-id="presentation_mode_label">Presentation Mode</span>-->
                <!--</button>-->

                <!--<button id="secondaryOpenFile${suffix}" class="secondaryToolbarButton openFile visibleLargeView" title="Open File" tabindex="52" data-l10n-id="open_file">-->
                    <!--<span data-l10n-id="open_file_label">Open</span>-->
                <!--</button>-->

                <!--<button id="secondaryPrint${suffix}" class="secondaryToolbarButton print visibleMediumView" title="Print" tabindex="53" data-l10n-id="print">-->
                    <!--<span data-l10n-id="print_label">Print</span>-->
                <!--</button>-->

                <!--<button id="secondaryDownload${suffix}" class="secondaryToolbarButton download visibleMediumView" title="Download" tabindex="54" data-l10n-id="download">-->
                    <!--<span data-l10n-id="download_label">Download</span>-->
                <!--</button>-->

                <!--<a href="#" id="secondaryViewBookmark${suffix}" class="secondaryToolbarButton bookmark visibleSmallView" title="Current view (copy or open in new window)" tabindex="55" data-l10n-id="bookmark">-->
                    <!--<span data-l10n-id="bookmark_label">Current View</span>-->
                <!--</a>-->

                <!--<div class="horizontalToolbarSeparator visibleLargeView"></div>-->

                <!--<button id="firstPage${suffix}" class="secondaryToolbarButton firstPage" title="Go to First Page" tabindex="56" data-l10n-id="first_page">-->
                    <!--<span data-l10n-id="first_page_label">Go to First Page</span>-->
                <!--</button>-->
                <!--<button id="lastPage${suffix}" class="secondaryToolbarButton lastPage" title="Go to Last Page" tabindex="57" data-l10n-id="last_page">-->
                    <!--<span data-l10n-id="last_page_label">Go to Last Page</span>-->
                <!--</button>-->

                <!--<div class="horizontalToolbarSeparator"></div>-->

                <!--<button id="pageRotateCw${suffix}" class="secondaryToolbarButton rotateCw" title="Rotate Clockwise" tabindex="58" data-l10n-id="page_rotate_cw">-->
                    <!--<span data-l10n-id="page_rotate_cw_label">Rotate Clockwise</span>-->
                <!--</button>-->
                <!--<button id="pageRotateCcw${suffix}" class="secondaryToolbarButton rotateCcw" title="Rotate Counterclockwise" tabindex="59" data-l10n-id="page_rotate_ccw">-->
                    <!--<span data-l10n-id="page_rotate_ccw_label">Rotate Counterclockwise</span>-->
                <!--</button>-->

                <!--<div class="horizontalToolbarSeparator"></div>-->

                <!--<button id="cursorSelectTool${suffix}" class="secondaryToolbarButton selectTool toggled" title="Enable Text Selection Tool" tabindex="60" data-l10n-id="cursor_text_select_tool">-->
                    <!--<span data-l10n-id="cursor_text_select_tool_label">Text Selection Tool</span>-->
                <!--</button>-->
                <!--<button id="cursorHandTool${suffix}" class="secondaryToolbarButton handTool" title="Enable Hand Tool" tabindex="61" data-l10n-id="cursor_hand_tool">-->
                    <!--<span data-l10n-id="cursor_hand_tool_label">Hand Tool</span>-->
                <!--</button>-->

                <!--<div class="horizontalToolbarSeparator"></div>-->

                <!--<button id="scrollVertical${suffix}" class="secondaryToolbarButton scrollModeButtons scrollVertical toggled" title="Use Vertical Scrolling" tabindex="62" data-l10n-id="scroll_vertical">-->
                    <!--<span data-l10n-id="scroll_vertical_label">Vertical Scrolling</span>-->
                <!--</button>-->
                <!--<button id="scrollHorizontal${suffix}" class="secondaryToolbarButton scrollModeButtons scrollHorizontal" title="Use Horizontal Scrolling" tabindex="63" data-l10n-id="scroll_horizontal">-->
                    <!--<span data-l10n-id="scroll_horizontal_label">Horizontal Scrolling</span>-->
                <!--</button>-->
                <!--<button id="scrollWrapped${suffix}" class="secondaryToolbarButton scrollModeButtons scrollWrapped" title="Use Wrapped Scrolling" tabindex="64" data-l10n-id="scroll_wrapped">-->
                    <!--<span data-l10n-id="scroll_wrapped_label">Wrapped Scrolling</span>-->
                <!--</button>-->

                <!--<div class="horizontalToolbarSeparator scrollModeButtons"></div>-->

                <!--<button id="spreadNone${suffix}" class="secondaryToolbarButton spreadModeButtons spreadNone toggled" title="Do not join page spreads" tabindex="65" data-l10n-id="spread_none">-->
                    <!--<span data-l10n-id="spread_none_label">No Spreads</span>-->
                <!--</button>-->
                <!--<button id="spreadOdd${suffix}" class="secondaryToolbarButton spreadModeButtons spreadOdd" title="Join page spreads starting with odd-numbered pages" tabindex="66" data-l10n-id="spread_odd">-->
                    <!--<span data-l10n-id="spread_odd_label">Odd Spreads</span>-->
                <!--</button>-->
                <!--<button id="spreadEven${suffix}" class="secondaryToolbarButton spreadModeButtons spreadEven" title="Join page spreads starting with even-numbered pages" tabindex="67" data-l10n-id="spread_even">-->
                    <!--<span data-l10n-id="spread_even_label">Even Spreads</span>-->
                <!--</button>-->

                <!--<div class="horizontalToolbarSeparator spreadModeButtons"></div>-->

                <!--<button id="documentProperties${suffix}" class="secondaryToolbarButton documentProperties" title="Document Properties…" tabindex="68" data-l10n-id="document_properties">-->
                    <!--<span data-l10n-id="document_properties_label">Document Properties…</span>-->
                <!--</button>-->
            <!--</div>-->
        <!--</div>  &lt;!&ndash; secondaryToolbar &ndash;&gt;-->

        <div class="toolbar">
            <div id="toolbarContainer">
                <div id="toolbarViewer${suffix}">
                    <div id="toolbarViewerLeft">
                        <!--<button id="sidebarToggle${suffix}" class="toolbarButton" title="Toggle Sidebar" tabindex="11" data-l10n-id="toggle_sidebar">-->
                            <!--<span data-l10n-id="toggle_sidebar_label">Toggle Sidebar</span>-->
                        <!--</button>-->
                        <div class="toolbarButtonSpacer"></div>
                        <button id="viewFind${suffix}" class="toolbarButton" title="Find in Document" tabindex="12" data-l10n-id="findbar">
                            <span data-l10n-id="findbar_label">Find</span>
                        </button>
                        <div class="splitToolbarButton hiddenSmallView">
                        
                            <button class="toolbarButton pageUp" title="Previous Page" id="previous${suffix}" tabindex="13" data-l10n-id="previous">
                                <span data-l10n-id="previous_label">Previous</span>
                            </button>
                            <button class="toolbarButton pageDown" title="Next Page" id="next${suffix}" tabindex="14" data-l10n-id="next">
                                <span data-l10n-id="next_label">Next</span>
                            </button>
                            
                    
                        </div>
                        <input type="number" id="pageNumber${suffix}" class="toolbarField pageNumber" title="Page" value="1" size="4" min="1" tabindex="15" data-l10n-id="page">
                        <span id="numPages${suffix}" class="toolbarLabel"></span>
                    </div>
                    <div id="toolbarViewerRight">
                        <!--<button id="presentationMode${suffix}" class="toolbarButton presentationMode hiddenLargeView" title="Switch to Presentation Mode" tabindex="31" data-l10n-id="presentation_mode">-->
                            <!--<span data-l10n-id="presentation_mode_label">Presentation Mode</span>-->
                        <!--</button>-->

                        <!--<button id="openFile${suffix}" class="toolbarButton openFile hiddenLargeView" title="Open File" tabindex="32" data-l10n-id="open_file">-->
                            <!--<span data-l10n-id="open_file_label">Open</span>-->
                        <!--</button>-->

                        <button id="print${suffix}" class="toolbarButton print hiddenMediumView" title="Print" tabindex="33" data-l10n-id="print">
                            <span data-l10n-id="print_label">Print</span>
                        </button>
                        
                        <!--AECWorks  在toolbar中添加手型工具和文本选择工具-->
                            <button class="toolbarButton handTool toggled" title="Enable Hand Tool" id="cursorHandTool${suffix}" tabindex="14" data-l10n-id="cursor_hand_tool">
                                <span data-l10n-id="cursor_hand_tool_label">Hand Tool</span>
                            </button>
                            <button class="toolbarButton selectTool" title="Enable Text Selection Tool" id="cursorSelectTool${suffix}" tabindex="14" data-l10n-id="cursor_text_select_tool">
                                <span data-l10n-id="cursor_text_select_tool_label">Text Selection Tool</span>
                            </button>
                            
                            
                            <!--手型工具原始代码-->
                            <!--<button id="cursorSelectTool${suffix}" class="secondaryToolbarButton selectTool toggled" title="Enable Text Selection Tool" tabindex="60" data-l10n-id="cursor_text_select_tool">-->
                                <!--<span data-l10n-id="cursor_text_select_tool_label">Text Selection Tool</span>-->
                            <!--</button>-->
                            <!--<button id="cursorHandTool${suffix}" class="secondaryToolbarButton handTool" title="Enable Hand Tool" tabindex="61" data-l10n-id="cursor_hand_tool">-->
                                <!--<span data-l10n-id="cursor_hand_tool_label">Hand Tool</span>-->
                            <!--</button>-->
                        
                        
                        

                        <!--<button id="download${suffix}" class="toolbarButton download hiddenMediumView" title="Download" tabindex="34" data-l10n-id="download">-->
                            <!--<span data-l10n-id="download_label">Download</span>-->
                        <!--</button>-->
                        <!--<a href="#" id="viewBookmark${suffix}" class="toolbarButton bookmark hiddenSmallView" title="Current view (copy or open in new window)" tabindex="35" data-l10n-id="bookmark">-->
                            <!--<span data-l10n-id="bookmark_label">Current View</span>-->
                        <!--</a>-->

                        <!--<div class="verticalToolbarSeparator hiddenSmallView"></div>-->

                        <!--<button id="secondaryToolbarToggle${suffix}" class="toolbarButton" title="Tools" tabindex="36" data-l10n-id="tools">-->
                            <!--<span data-l10n-id="tools_label">Tools</span>-->
                        <!--</button>-->
                    </div>
                    <div id="toolbarViewerMiddle">
                        <div class="splitToolbarButton">
                            <button id="zoomOut${suffix}" class="toolbarButton zoomOut" title="Zoom Out" tabindex="21" data-l10n-id="zoom_out">
                                <span data-l10n-id="zoom_out_label">Zoom Out</span>
                            </button>
                            <div class="splitToolbarButtonSeparator"></div>
                            <button id="zoomIn${suffix}" class="toolbarButton zoomIn" title="Zoom In" tabindex="22" data-l10n-id="zoom_in">
                                <span data-l10n-id="zoom_in_label">Zoom In</span>
                            </button>
                        </div>
                        <span id="scaleSelectContainer${suffix}" class="dropdownToolbarButton">
                  <select id="scaleSelect${suffix}" title="Zoom" tabindex="23" data-l10n-id="zoom">
                    <option id="pageAutoOption" title="" value="auto" selected="selected" data-l10n-id="page_scale_auto">Automatic Zoom</option>
                    <option id="pageActualOption" title="" value="page-actual" data-l10n-id="page_scale_actual">Actual Size</option>
                    <option id="pageFitOption" title="" value="page-fit" data-l10n-id="page_scale_fit">Page Fit</option>
                    <option id="pageWidthOption" title="" value="page-width" data-l10n-id="page_scale_width">Page Width</option>
                    <option id="customScaleOption${suffix}" title="" value="custom" disabled="disabled" hidden="true"></option>
                    <option title="" value="0.5" data-l10n-id="page_scale_percent" data-l10n-args='{ "scale": 50 }'>50%</option>
                    <option title="" value="0.75" data-l10n-id="page_scale_percent" data-l10n-args='{ "scale": 75 }'>75%</option>
                    <option title="" value="1" data-l10n-id="page_scale_percent" data-l10n-args='{ "scale": 100 }'>100%</option>
                    <option title="" value="1.25" data-l10n-id="page_scale_percent" data-l10n-args='{ "scale": 125 }'>125%</option>
                    <option title="" value="1.5" data-l10n-id="page_scale_percent" data-l10n-args='{ "scale": 150 }'>150%</option>
                    <option title="" value="2" data-l10n-id="page_scale_percent" data-l10n-args='{ "scale": 200 }'>200%</option>
                    <option title="" value="3" data-l10n-id="page_scale_percent" data-l10n-args='{ "scale": 300 }'>300%</option>
                    <option title="" value="4" data-l10n-id="page_scale_percent" data-l10n-args='{ "scale": 400 }'>400%</option>
                  </select>
                </span>
                    </div>
                </div>
                <div id="loadingBar">
                    <div class="progress">
                        <div class="glimmer">
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <menu type="context" id="viewerContextMenu">
            <menuitem id="contextFirstPage${suffix}" label="First Page"
                      data-l10n-id="first_page"></menuitem>
            <menuitem id="contextLastPage${suffix}" label="Last Page"
                      data-l10n-id="last_page"></menuitem>
            <menuitem id="contextPageRotateCw${suffix}" label="Rotate Clockwise"
                      data-l10n-id="page_rotate_cw"></menuitem>
            <menuitem id="contextPageRotateCcw${suffix}" label="Rotate Counter-Clockwise"
                      data-l10n-id="page_rotate_ccw"></menuitem>
        </menu>

        <div id='viewerContainer${suffix}' tabindex="0">
            <div id="viewer${suffix}" class="pdfViewer"></div>
        </div>

        <div id="errorWrapper${suffix}" hidden='true'>
            <div id="errorMessageLeft">
                <span id="errorMessage${suffix}"></span>
                <button id="errorShowMore${suffix}" data-l10n-id="error_more_info">
                    More Information
                </button>
                <button id="errorShowLess${suffix}" data-l10n-id="error_less_info" hidden='true'>
                    Less Information
                </button>
            </div>
            <div id="errorMessageRight">
                <button id="errorClose${suffix}" data-l10n-id="error_close">
                    Close
                </button>
            </div>
            <div class="clearBoth"></div>
            <textarea id="errorMoreInfo${suffix}" hidden='true' readonly="readonly"></textarea>
        </div>
    </div><!-- mainContainer -->

<div id="overlayContainer" class="hidden">
        <div id="passwordOverlay${suffix}" class="container hidden">
            <div class="dialog">
                <div class="row">
                    <p id="passwordText${suffix}" data-l10n-id="password_label">Enter the password to open this PDF file:</p>
                </div>
                <div class="row">
                    <input type="password" id="password${suffix}" class="toolbarField">
                </div>
                <div class="buttonRow">
                    <button id="passwordCancel${suffix}" class="overlayButton"><span data-l10n-id="password_cancel">Cancel</span></button>
                    <button id="passwordSubmit${suffix}" class="overlayButton"><span data-l10n-id="password_ok">OK</span></button>
                </div>
            </div>
        </div>
        <!--<div id="documentPropertiesOverlay${suffix}" class="container hidden">-->
            <!--<div class="dialog">-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_file_name">File name:</span> <p id="fileNameField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_file_size">File size:</span> <p id="fileSizeField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="separator"></div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_title">Title:</span> <p id="titleField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_author">Author:</span> <p id="authorField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_subject">Subject:</span> <p id="subjectField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_keywords">Keywords:</span> <p id="keywordsField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_creation_date">Creation Date:</span> <p id="creationDateField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_modification_date">Modification Date:</span> <p id="modificationDateField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_creator">Creator:</span> <p id="creatorField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="separator"></div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_producer">PDF Producer:</span> <p id="producerField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_version">PDF Version:</span> <p id="versionField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_page_count">Page Count:</span> <p id="pageCountField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_page_size">Page Size:</span> <p id="pageSizeField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="separator"></div>-->
                <!--<div class="row">-->
                    <!--<span data-l10n-id="document_properties_linearized">Fast Web View:</span> <p id="linearizedField${suffix}">-</p>-->
                <!--</div>-->
                <!--<div class="buttonRow">-->
                    <!--<button id="documentPropertiesClose${suffix}" class="overlayButton"><span data-l10n-id="document_properties_close">Close</span></button>-->
                <!--</div>-->
            <!--</div>-->
        <!--</div>-->
        <div id="printServiceOverlay" class="container hidden">
            <div class="dialog">
                <div class="row">
                    <span data-l10n-id="print_progress_message">Preparing document for printing…</span>
                </div>
                <div class="row">
                    <progress value="0" max="100"></progress>
                    <span data-l10n-id="print_progress_percent" data-l10n-args='{ "progress": 0 }' class="relative-progress">0%</span>
                </div>
                <div class="buttonRow">
                    <button id="printCancel" class="overlayButton"><span data-l10n-id="print_progress_close">Cancel</span></button>
                </div>
            </div>
        </div>
    </div><!-- overlayContainer -->`;
            return outerDiv;
        }

        createViewerUI(assemblyId) {
            const viewerContainer = this.createViewerContainer(assemblyId);
            const outerContainer = this.createOuterContainer(assemblyId);
            viewerContainer.appendChild(outerContainer);
            document.body.appendChild(viewerContainer);
        }

        getViewerConfiguration(assemblyId) {
            const suffix=assemblyId.suffix;
            // 保留一份原始的appConfig
            /*return {
                // 注意制定 app 的容器，是一个 div， 不是body了
                appContainer: document.getElementById('exampleViewerContainer'),
                mainContainer: document.getElementById('viewerContainer'),
                viewerContainer: document.getElementById('viewer'),
                eventBus: null, // using global event bus with DOM events
                toolbar: {
                    container: document.getElementById('toolbarViewer'),
                    numPages: document.getElementById('numPages'),
                    pageNumber: document.getElementById('pageNumber'),
                    scaleSelectContainer: document.getElementById('scaleSelectContainer'),
                    scaleSelect: document.getElementById('scaleSelect'),
                    customScaleOption: document.getElementById('customScaleOption'),
                    previous: document.getElementById('previous'),
                    next: document.getElementById('next'),
                    zoomIn: document.getElementById('zoomIn'),
                    zoomOut: document.getElementById('zoomOut'),
                    viewFind: document.getElementById('viewFind'),
                    openFile: document.getElementById('openFile'),
                    print: document.getElementById('print'),
                    presentationModeButton: document.getElementById('presentationMode'),
                    download: document.getElementById('download'),
                    viewBookmark: document.getElementById('viewBookmark'),
                },
                secondaryToolbar: {
                    toolbar: document.getElementById('secondaryToolbar'),
                    toggleButton: document.getElementById('secondaryToolbarToggle'),
                    toolbarButtonContainer: document.getElementById('secondaryToolbarButtonContainer'),
                    presentationModeButton: document.getElementById('secondaryPresentationMode'),
                    openFileButton: document.getElementById('secondaryOpenFile'),
                    printButton: document.getElementById('secondaryPrint'),
                    downloadButton: document.getElementById('secondaryDownload'),
                    viewBookmarkButton: document.getElementById('secondaryViewBookmark'),
                    firstPageButton: document.getElementById('firstPage'),
                    lastPageButton: document.getElementById('lastPage'),
                    pageRotateCwButton: document.getElementById('pageRotateCw'),
                    pageRotateCcwButton: document.getElementById('pageRotateCcw'),
                    cursorSelectToolButton: document.getElementById('cursorSelectTool'),
                    cursorHandToolButton: document.getElementById('cursorHandTool'),
                    scrollVerticalButton: document.getElementById('scrollVertical'),
                    scrollHorizontalButton: document.getElementById('scrollHorizontal'),
                    scrollWrappedButton: document.getElementById('scrollWrapped'),
                    spreadNoneButton: document.getElementById('spreadNone'),
                    spreadOddButton: document.getElementById('spreadOdd'),
                    spreadEvenButton: document.getElementById('spreadEven'),
                    documentPropertiesButton: document.getElementById('documentProperties'),
                },
                fullscreen: {
                    contextFirstPage: document.getElementById('contextFirstPage'),
                    contextLastPage: document.getElementById('contextLastPage'),
                    contextPageRotateCw: document.getElementById('contextPageRotateCw'),
                    contextPageRotateCcw: document.getElementById('contextPageRotateCcw'),
                },
                sidebar: {
                    // Divs (and sidebar button)
                    outerContainer: document.getElementById(`outerContainer${suffix}`),
                    viewerContainer: document.getElementById('viewerContainer'),
                    toggleButton: document.getElementById('sidebarToggle'),
                    // Buttons
                    thumbnailButton: document.getElementById('viewThumbnail'),
                    outlineButton: document.getElementById('viewOutline'),
                    attachmentsButton: document.getElementById('viewAttachments'),
                    // Views
                    thumbnailView: document.getElementById('thumbnailView'),
                    outlineView: document.getElementById('outlineView'),
                    attachmentsView: document.getElementById('attachmentsView'),
                },
                sidebarResizer: {
                    outerContainer: document.getElementById(`outerContainer${suffix}`),
                    resizer: document.getElementById('sidebarResizer'),
                },
                findBar: {
                    bar: document.getElementById('findbar'),
                    toggleButton: document.getElementById('viewFind'),
                    findField: document.getElementById('findInput'),
                    highlightAllCheckbox: document.getElementById('findHighlightAll'),
                    caseSensitiveCheckbox: document.getElementById('findMatchCase'),
                    entireWordCheckbox: document.getElementById('findEntireWord'),
                    findMsg: document.getElementById('findMsg'),
                    findResultsCount: document.getElementById('findResultsCount'),
                    findPreviousButton: document.getElementById('findPrevious'),
                    findNextButton: document.getElementById('findNext'),
                },
                passwordOverlay: {
                    overlayName: 'passwordOverlay',
                    container: document.getElementById('passwordOverlay'),
                    label: document.getElementById('passwordText'),
                    input: document.getElementById('password'),
                    submitButton: document.getElementById('passwordSubmit'),
                    cancelButton: document.getElementById('passwordCancel'),
                },
                documentProperties: {
                    overlayName: 'documentPropertiesOverlay',
                    container: document.getElementById('documentPropertiesOverlay'),
                    closeButton: document.getElementById('documentPropertiesClose'),
                    fields: {
                        fileName: document.getElementById('fileNameField'),
                        fileSize: document.getElementById('fileSizeField'),
                        title: document.getElementById('titleField'),
                        author: document.getElementById('authorField'),
                        subject: document.getElementById('subjectField'),
                        keywords: document.getElementById('keywordsField'),
                        creationDate: document.getElementById('creationDateField'),
                        modificationDate: document.getElementById('modificationDateField'),
                        creator: document.getElementById('creatorField'),
                        producer: document.getElementById('producerField'),
                        version: document.getElementById('versionField'),
                        pageCount: document.getElementById('pageCountField'),
                        pageSize: document.getElementById('pageSizeField'),
                        linearized: document.getElementById('linearizedField'),
                    },
                },
                errorWrapper: {
                    container: document.getElementById('errorWrapper'),
                    errorMessage: document.getElementById('errorMessage'),
                    closeButton: document.getElementById('errorClose'),
                    errorMoreInfo: document.getElementById('errorMoreInfo'),
                    moreInfoButton: document.getElementById('errorShowMore'),
                    lessInfoButton: document.getElementById('errorShowLess'),
                },
                // printContainer: document.getElementById('printContainer'),
                openFileInputName: 'fileInput',
                debuggerScriptPath: './debugger.js',
            };*/
            return {
                // 注意制定 app 的容器，是一个 div， 不是body了
                appContainer: document.getElementById(`${assemblyId.prefix}${assemblyId.suffix}`),
                mainContainer: document.getElementById(`viewerContainer${suffix}`),
                viewerContainer: document.getElementById(`viewer${suffix}`),
                eventBus: this.docViewer.eventBus, // using global event bus with DOM events
                toolbar: {
                    container: document.getElementById(`toolbarViewer${suffix}`),
                    numPages: document.getElementById(`numPages${suffix}`),
                    pageNumber: document.getElementById(`pageNumber${suffix}`),
                    scaleSelectContainer: document.getElementById(`scaleSelectContainer${suffix}`),
                    scaleSelect: document.getElementById(`scaleSelect${suffix}`),
                    customScaleOption: document.getElementById(`customScaleOption${suffix}`),
                    previous: document.getElementById(`previous${suffix}`),
                    next: document.getElementById(`next${suffix}`),
                    zoomIn: document.getElementById(`zoomIn${suffix}`),
                    zoomOut: document.getElementById(`zoomOut${suffix}`),
                    viewFind: document.getElementById(`viewFind${suffix}`),
                    print: document.getElementById(`print${suffix}`),
                    cursorSelectToolButton: document.getElementById(`cursorSelectTool${suffix}`),
                    cursorHandToolButton: document.getElementById(`cursorHandTool${suffix}`),
                },

                fullscreen: {
                    contextFirstPage: document.getElementById(`contextFirstPage${suffix}`),
                    contextLastPage: document.getElementById(`contextLastPage${suffix}`),
                    contextPageRotateCw: document.getElementById(`contextPageRotateCw${suffix}`),
                    contextPageRotateCcw: document.getElementById(`contextPageRotateCcw${suffix}`),
                },
                findBar: {
                    bar: document.getElementById(`findbar${suffix}`),
                    toggleButton: document.getElementById(`viewFind${suffix}`),
                    findField: document.getElementById(`findInput${suffix}`),
                    highlightAllCheckbox: document.getElementById(`findHighlightAll${suffix}`),
                    caseSensitiveCheckbox: document.getElementById(`findMatchCase${suffix}`),
                    entireWordCheckbox: document.getElementById(`findEntireWord${suffix}`),
                    findMsg: document.getElementById(`findMsg${suffix}`),
                    findResultsCount: document.getElementById(`findResultsCount${suffix}`),
                    findPreviousButton: document.getElementById(`findPrevious${suffix}`),
                    findNextButton: document.getElementById(`findNext${suffix}`),
                },
                passwordOverlay: {
                    overlayName: `passwordOverlay${suffix}`,
                    container: document.getElementById(`passwordOverlay${suffix}`),
                    label: document.getElementById(`passwordText${suffix}`),
                    input: document.getElementById(`password${suffix}`),
                    submitButton: document.getElementById(`passwordSubmit${suffix}`),
                    cancelButton: document.getElementById(`passwordCancel${suffix}`),
                },
                errorWrapper: {
                    container: document.getElementById(`errorWrapper${suffix}`),
                    errorMessage: document.getElementById(`errorMessage${suffix}`),
                    closeButton: document.getElementById(`errorClose${suffix}`),
                    errorMoreInfo: document.getElementById(`errorMoreInfo${suffix}`),
                    moreInfoButton: document.getElementById(`errorShowMore${suffix}`),
                    lessInfoButton: document.getElementById(`errorShowLess${suffix}`),
                },
                openFileInputName: `fileInput${suffix}`,
                debuggerScriptPath: './debugger.js',
            };
        }

        analyze(id){
            if(id.indexOf('-') < 0){
                return;
            }
            const strikeIndex=id.indexOf('-');
            const prefix=id.substring(0,strikeIndex);
            const suffix=id.substring(strikeIndex,id.length);
            return {prefix,suffix}
        }

        loadViewer(appContainerId,inputUrnId) {
            const assemblyId=this.analyze(appContainerId);
            this.createViewerUI(assemblyId);
            let config = this.getViewerConfiguration(assemblyId);
            config.docFileLoader = new DocFileLoader(inputUrnId);
            this.docViewer.webViewerLoad(config);
        }

        unloadViewer(id){
            this.docViewer.dispose();
            const viewerContainer=document.getElementById(id);
            document.body.removeChild(viewerContainer);
            this.docViewer = undefined;
        }
    }


    let loadBtn=document.getElementById('load');
    let unloadBtn=document.getElementById('unload');
    let myViewer1,myViewer2;
    loadBtn.addEventListener('click',function(){
        myViewer1 = new MyGuiViewer();
        myViewer1.loadViewer('exampleViewerContainer-1','fileUrn1');
        myViewer2 = new MyGuiViewer();
        myViewer2.loadViewer('exampleViewerContainer-2','fileUrn2');
    });
    unloadBtn.addEventListener('click',function(){
        myViewer1.unloadViewer('exampleViewerContainer-1');
        myViewer1 = undefined;
        myViewer2.unloadViewer('exampleViewerContainer-2');
        myViewer2 = undefined;
    })
});
